<?php
/*
 * $Horde: kronolith/day.php,v 1.36.2.1 2002/03/19 02:10:40 chuck Exp $
 *
 * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('KRONOLITH_BASE', dirname(__FILE__));
require_once KRONOLITH_BASE . '/lib/base.php';
require_once KRONOLITH_BASE . '/lib/DayView.php';

$month = Horde::getFormData('month');
$day = Horde::getFormData('mday');
$year = Horde::getFormData('year');
$timestamp = Horde::getFormData('timestamp');
$dayOb = new Kronolith_DayView($month, $day, $year, $timestamp);
$title = $dayOb->Day->getTime($prefs->getValue('date_format'));
$js_onLoad = null;

if ($conf['compress_pages']) {
    ob_start('ob_gzhandler');
}

require KRONOLITH_TEMPLATES . '/common-header.inc';
require './menu.php';

$dayOb->html(KRONOLITH_TEMPLATES);

require KRONOLITH_TEMPLATES . '/common-footer.inc';

?>
